/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.servlet;

import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.servlet.DispatcherServlet;
import org.springframework.web.servlet.HandlerExecutionChain;

import javax.servlet.http.HttpServletRequest;

public class FailSafeDispatcherServlet extends DispatcherServlet {
  private static final long serialVersionUID = -3804257359099120923L;
  public final HandlerExecutionChain notFoundHandler;

  public FailSafeDispatcherServlet() {
    notFoundHandler = newNotFoundHandler();
  }

  public FailSafeDispatcherServlet(WebApplicationContext webApplicationContext) {
    super(webApplicationContext);
    notFoundHandler = newNotFoundHandler();
  }

  @Override
  protected HandlerExecutionChain getHandler(HttpServletRequest request) throws Exception {
    HandlerExecutionChain handler = super.getHandler(request);
    if (handler == null) {
      return notFoundHandler;
    }
    return handler;
  }

  private HandlerExecutionChain newNotFoundHandler() {
    return new HandlerExecutionChain(new FailSafeController());
  }
}
